@@ -33,14 +33,16 @@ class Evaluator():
                 if arg_match:
                     arg_str = arg_match.group(1).strip()
                     arg_str = self.__replace_vars(arg_str, context)
-                    # print('---')
-                    # print('--arg_str--', arg_str)
-                    # print('---')
+                    print('---')
+                    print('--arg_str--', arg_str)
+                    print('---')
                     args = eval(f"dict({arg_str})")
                 if func in self.functions:
                     result = self.functions[func](**args)
+                    print('--expr--', expr)
+                    print('--result--', result)
                     expr = re.sub(
-                        f'\\\\@{func}\\([^\\)]+\\)', str(result), expr, 1)
+                        f"\\\\@{func}\\((?<!')(.*?)\\)(?!')", str(result), expr, 1)
                 else:
                     log.warning(f"Function '{func}' is not defined.")
         return expr
